/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api.classlocator;

import java.net.URL;

import org.ow2.util.archive.api.ArchiveException;
import org.ow2.util.archive.api.IArchive;
import org.ow2.util.scan.api.IClassesLocator;

/**
 * This class add notion of class to an archive.
 * @author Gael Lalire
 */
public class ArchiveClassesLocator implements IClassesLocator {

    /**
     * Archive.
     */
    private IArchive archive;

    /**
     * @param archive an archive which contains classes
     */
    public ArchiveClassesLocator(final IArchive archive) {
        this.archive = archive;
    }

    /**
     * @param className the class name
     * @return the url of the class named className
     */
    public URL getClassURL(final String className) {
        try {
            return archive.getResource(className.replace('.', '/').concat(".class"));
        } catch (ArchiveException e) {
            return null;
        }
    }

}
