/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api.visitor;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.IType;

/**
 * This class manages the handling of Array[] type like String[] value().
 * @param <T> the type of class / erasure (for values).
 * @author Florent Benoit
 */
public abstract class ObjectArrayAnnotationVisitor<T> extends DefaultAnnotationVisitor<List<T>>{

    /**
     * Visits a primitive value of the annotation.
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link IType}.
     */
    @Override
    @SuppressWarnings("unchecked")
    public void visit(final String name, final Object value, IAnnotationVisitorContext<List<T>> visitorContext) {
        List<T> list = visitorContext.getLocal();
        list.add((T) value);
    }

    @Override
    public List<T> buildInstance() {
        return new ArrayList<>();
    }

}
