/**
 * Copyright 2006-2012 Bull S.A.S.
 * Copyright 2013 Peergreen S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.impl;

import java.lang.annotation.ElementType;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.ow2.util.asm.AnnotationVisitor;
import org.ow2.util.asm.commons.EmptyVisitor;
import org.ow2.util.scan.api.IAnnotationVisitor;
import org.ow2.util.scan.api.configurator.IAnnotationConfigurator;
import org.ow2.util.scan.api.configurator.ISessionConfigurator;
import org.ow2.util.scan.api.metadata.IMetadata;
import org.ow2.util.scan.api.metadata.structures.IAnnotation;
import org.ow2.util.scan.impl.metadata.JAnnotation;

/**
 * super class of all scanner.
 * @author Florent Benoit
 * @author Gael Lalire
 */
public class ScanCommonVisitor extends EmptyVisitor {

    /**
     *  Configurator of this session
     */
    private final ISessionConfigurator sessionConfigurator;

    /**
     * Type of the element.
     */
    private final ElementType elementType;

    /**
     * Result
     */
    private final ScannerResult scannerResult;


    private final Map<String, IAnnotationVisitor<?>> annotationVisitors;

    private IMetadata metadata;


    public void setMetadata(IMetadata metadata) {
        this.metadata = metadata;
    }

    /**
     * @return session configurator
     */
    protected ISessionConfigurator getSessionConfigurator() {
        return sessionConfigurator;
    }

    public ScannerResult getScannerResult() {
        return scannerResult;
    }



    public ScanCommonVisitor(ISessionConfigurator sessionConfigurator, ScannerResult scannerResult, ElementType elementType) {
        this.sessionConfigurator = sessionConfigurator;
        this.scannerResult = scannerResult;
        this.elementType = elementType;

        // init annotation processors available
        List<IAnnotationConfigurator> annotationConfigurators = sessionConfigurator.getAnnotationConfigurators();
        this.annotationVisitors = new HashMap<>();
        for (IAnnotationConfigurator annotationConfigurator : annotationConfigurators) {
            this.annotationVisitors.putAll(annotationConfigurator.filter(elementType));
        }

    }

    /**
     * @param name annotation name
     * @param visible annotation visibility
     * @return a visitor
     */
    @SuppressWarnings("rawtypes")
    @Override
    public AnnotationVisitor visitAnnotation(final String name, final boolean visible) {
        IAnnotation jAnnotation = new JAnnotation(name, visible);
        metadata.addAnnotation(jAnnotation);
        IAnnotationVisitor annotationVisitor = annotationVisitors.get(name);
        return new ScanAnnotationVisitor(Collections.singletonList(annotationVisitor), metadata);
    }

    public ElementType getElementType() {
        return elementType;
    }

}
