/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.impl;

import java.lang.annotation.ElementType;

import org.ow2.util.asm.FieldVisitor;
import org.ow2.util.scan.api.configurator.IFieldConfigurator;
import org.ow2.util.scan.api.configurator.ISessionConfigurator;
import org.ow2.util.scan.api.metadata.IMetadata;

/**
 * ScanFieldVisitor.
 * @author Gael Lalire
 */
public final class ScanFieldVisitor extends ScanCommonVisitor implements FieldVisitor {

    /**
     */
    private final IFieldConfigurator fieldConfigurator;

    /**
     * Construtor.
     * @param fieldConfigurators configurators
     * @param referencedClasses a set to complete with referenced classes name.
     */
    public ScanFieldVisitor(ISessionConfigurator sessionConfigurator, IFieldConfigurator fieldConfigurator, IMetadata metadata, ScannerResult scannerResult) {
        super(sessionConfigurator, scannerResult, ElementType.FIELD);
        setMetadata(metadata);
        this.fieldConfigurator = fieldConfigurator;
    }

    /**
     * call configurationComplete on each configurator.
     */
    @Override
    public void visitEnd() {
        fieldConfigurator.configurationComplete(getScannerResult());
    }

}
