/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.impl;

import java.lang.annotation.ElementType;

import org.ow2.util.asm.MethodVisitor;
import org.ow2.util.scan.api.configurator.IMethodConfigurator;
import org.ow2.util.scan.api.configurator.ISessionConfigurator;
import org.ow2.util.scan.api.metadata.IMetadata;

/**
 * ScanMethodVisitor.
 * @author Gael Lalire
 */
public final class ScanMethodVisitor extends ScanCommonVisitor implements MethodVisitor {

    /**
     * A set to complete with referenced classes name.
     */
    private final IMethodConfigurator methodConfigurator;

    /**
     * Constructor.
     * @param methodConfigurators configurators
     * @param referencedClasses a set to complete with referenced classes name.
     */
    public ScanMethodVisitor(final ISessionConfigurator sessionConfigurator, final IMethodConfigurator methodConfigurator, IMetadata metadata, ScannerResult scannerResult) {
        super(sessionConfigurator, scannerResult, ElementType.METHOD);
        setMetadata(metadata);
        this.methodConfigurator = methodConfigurator;
    }

    /**
     * call configurationCompleteon each configurator.
     */
    @Override
    public void visitEnd() {
        methodConfigurator.configurationComplete(getScannerResult());
    }

}
