/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.impl.metadata;

import java.lang.annotation.ElementType;

import org.ow2.util.asm.Type;
import org.ow2.util.scan.api.metadata.CommonMetadata;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.api.metadata.IFieldMetadata;
import org.ow2.util.scan.api.metadata.structures.IField;
import org.ow2.util.scan.api.metadata.structures.IMember;

/**
 * This class represents the annotation metadata of a field.
 * @author Florent Benoit
 */
public class FieldMetadata extends CommonMetadata implements IFieldMetadata {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 6915512495541617868L;

    /**
     * Method on which we got metadata.
     */
    private IField jField = null;

    /**
     * Parent metadata.
     */
    private IClassMetadata classAnnotationMetadata = null;

    /**
     * This field is a field from a super class ?<br>
     */
    private boolean inherited = false;


    /**
     * Constructor.
     * @param jField the field on which we will set/add metadata
     * @param classAnnotationMetadata the parent metadata.
     */
    public FieldMetadata(final IField jField, final IClassMetadata classAnnotationMetadata) {
        this.jField = jField;
        this.classAnnotationMetadata = classAnnotationMetadata;
        setParent(classAnnotationMetadata);
    }

    /**
     * @return JMethod object
     */
    @Override
    public IField getJField() {
        return this.jField;
    }

    /**
     * @return true if this method is inherited from a super class
     */
    public boolean isInherited() {
        return inherited;
    }

    /**
     * Sets the inheritance of this method.
     * @param inherited true if method is from a super class
     */
    public void setInherited(final boolean inherited) {
        this.inherited = inherited;
    }

    /**
     * @return parent metadata (class)
     */
    @Override
    public IClassMetadata getClassMetadata() {
        return classAnnotationMetadata;
    }

    @Override
    protected ElementType getElementType() {
        return ElementType.FIELD;
    }

    @Override
    public IMember getMember() {
        return getJField();
    }

    @Override
    public String getType() {
        Type type = Type.getType(jField.getDescriptor());
        return type.getClassName();
    }

}
